.. _acknowledgments:

***************
Acknowledgments
***************

The development of this open source software was funded by the `Helmholtz
School for Data Science in Life, Earth and Energy (HDS-LEE)
<http://www.hds-lee.de>`_ and  the `Human Brain Project
<http://www.humanbrainproject.eu>`_, funded from the European Union’s Horizon
2020 Framework Programme for Research and Innovation under Specific Grant
Agreements No. 785907 and No. 945539 (Human Brain Project SGA2 and SGA3).
